@@ -1,4 +1,6 @@
 """Command-line interface."""
+import atexit
+
 import typer
 
 from gwdcli.events import app as events_app
@@ -10,4 +12,5 @@ app.add_typer(events_app, name="events")
 typer_click_object = typer.main.get_command(app)
 
 if __name__ == "__main__":
+    atexit.register(lambda: print("\x1b[?25h"))
     app()
